Added support for a WINELOADER environment variable which allows the
specification of a different binary loader.

diff --git a/scheduler/process.c b/scheduler/process.c
index 795527b..730ce63 100644
--- a/scheduler/process.c
+++ b/scheduler/process.c
@@ -622,7 +622,12 @@
 {
     const char *path, *pos, *ptr;
 
-    /* first try bin directory */
+    /* first, try for a WINELOADER environment variable */
+    argv[0] = getenv("WINELOADER");
+    if (argv[0])
+        execve( argv[0], argv, envp );
+
+    /* next, try bin directory */
     argv[0] = BINDIR "/wine";
     execve( argv[0], argv, envp );